@@ -6,7 +6,7 @@ use MooseX::StrictConstructor;
 
 use namespace::clean -except => 'meta';
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 
 #======================================================================
 # ATTRIBUTES
@@ -24,7 +24,9 @@ has 'type'        => (is => 'ro', isa => 'Str', builder => '_type', lazy => 1);
 
 sub _type {
   my ($self) = @_;
+
   my ($type) = $self->code =~ /^\s*(\w+)/; 
+  $type    //= "";
   return uc($type);
 }
 
@@ -120,5 +122,4 @@ Laurent Dami, E<lt>dami AT cpan DOT org<gt>
 
 Copyright 2024 by Laurent Dami.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This program is free software, you can redistribute it and/or modify it under the terms of the Artistic License version 2.0.
